/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: GuiWords.h,v 1.10 2014/01/07 23:44:46 bowkenken Exp $
***************************************************************/

#ifndef GUI_WORDS_H
#define GUI_WORDS_H	1

////////////////////////////////////////////////////////////////
// 쥦ɥ
////////////////////////////////////////////////////////////////

class GuiWords {

	//////// ץ饤١ȡСѿ ////////
private:

#ifdef D_WS
#endif // D_WS

#ifdef D_GTK
	GtkWidget *mWordsTextScroll;
	GtkWidget *mWordsTextView;
	GtkWidget *mButtonOk;
#endif // D_GTK

#ifdef D_MFC
#endif // D_MFC

	//////// ѥ֥åСѿ ////////
public:

#ifdef D_WS
	void *mWordsWin;
#endif // D_WS

#ifdef D_GTK
	GtkWidget *mWordsWin;
#endif // D_GTK

#ifdef D_MAC
	void *mWordsWin;
#endif // D_MAC

#ifdef D_IPHONE
	void *mWordsWin;
#endif // D_IPHONE

#ifdef D_MFC
	class CWordsDlg *mWordsWin;
#endif // D_MFC

	//////// ѥ֥åСؿ ////////
public:

	GuiWords();
	~GuiWords();
	void init();
	void destroy();

	void draw( const char *name, const char *str, long w = -1 );
	void redraw();
	void wipe();

	void okClicked();

	//////// ץ饤١ȡСؿ ////////
private:

	void newWin();
};

#endif /* GUI_WORDS_H */
